@@ -1,14 +1,21 @@
 (* approx: proxy server for Debian archive files
-   Copyright (C) 2007  Eric C. Cooper <ecc@cmu.edu>
+   Copyright (C) 2010  Eric C. Cooper <ecc@cmu.edu>
    Released under the GNU General Public License *)
 
 open Printf
 open Util
 
+let verbose = ref false
+
 let file =
-  match Array.length Sys.argv with
-  | 2 -> Sys.argv.(1)
-  | _ -> eprintf "Usage: %s control-file\n" Sys.argv.(0); exit 1
+  match Sys.argv with
+  | [| _; file |] -> file
+  | [| _; "-v"; file |] | [| _; "--verbose"; file |] ->
+      verbose := true;
+      file
+  | _ ->
+      eprintf "Usage: %s [-v] control-file\n" Sys.argv.(0);
+      exit 1
 
 let capitalize_parts str =
   join '-' (List.map String.capitalize (split '-' str))
@@ -28,7 +35,8 @@ let print_pair (field, value) =
       List.iter print_line lines
 
 let print_paragraph p =
-  List.iter print_pair p;
+  if !verbose then printf "[%d]\n" (Control_file.line_number p);
+  Control_file.iter_fields print_pair p;
   print_newline ()
 
 let () =
